@@ -6,7 +6,8 @@ from django.utils.translation import ugettext_lazy as _
 from django.db.models.fields import FieldDoesNotExist
 from django.core.exceptions import ImproperlyConfigured
 
-from model_utils.managers import QueryManager
+from model_utils.managers import manager_from, InheritanceCastMixin, \
+    QueryManager
 from model_utils.fields import AutoCreatedField, AutoLastModifiedField, \
     StatusField, MonitorField
 
@@ -20,6 +21,8 @@ class InheritanceCastModel(models.Model):
     """
     real_type = models.ForeignKey(ContentType, editable=False, null=True)
 
+    objects = manager_from(InheritanceCastMixin)
+
     def save(self, *args, **kwargs):
         if not self.id:
             self.real_type = self._get_real_type()
