@@ -8,12 +8,11 @@ parent = os.path.dirname(os.path.dirname(os.path.dirname(
 
 sys.path.insert(0, parent)
 
-from django.test.utils import get_runner
+from django.test.simple import run_tests
 from django.conf import settings
 
 def runtests():
-    test_runner = get_runner(settings)
-    failures = test_runner(['tests'], verbosity=1, interactive=True)
+    failures = run_tests(['tests'], verbosity=1, interactive=True)
     sys.exit(failures)
 
 if __name__ == '__main__':
